@@ -110,9 +110,12 @@ namespace Breeze
         //* frame background color
         QColor frameBackgroundColor( const QPalette&, QPalette::ColorGroup ) const;
 
-        //* frame background color
+        //* side panel background color
         QColor sidePanelBackgroundColor( const QPalette&, QPalette::ColorGroup ) const;
 
+        //* side panel foreground color
+        QColor sidePanelForegroundColor( const QPalette&, QPalette::ColorGroup ) const;
+
         //* return altered palette suitable for tinted frames
         QPalette framePalette( const QPalette& ) const;
 
@@ -233,7 +236,7 @@ namespace Breeze
         void renderArrow( QPainter*, const QRect&, const QColor&, ArrowOrientation ) const;
 
         //* generic button (for mdi decorations, tabs and dock widgets)
-        void renderButton( QPainter*, const QRect&, const QColor&, ButtonType, bool inverted ) const;
+        void renderDecorationButton( QPainter*, const QRect&, const QColor&, ButtonType, bool inverted ) const;
 
         //@}
 
